import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.List;

/** 
 *
 * A world of balloons.
 * 
 * Balloons will be created and flow from the bottom to the top of the screen.
 * 
 * @author Poul Henriksen
 */
public class DuckWorld extends World 
{
    ScoreCounter scorecounter = new ScoreCounter("Score: ");
    ShotCounter shotcounter = new ShotCounter("Shot: ");
    LevelInt levelint = new LevelInt("Level: ");
    
        
    public static int ducksSeen = 0;
    /**
     * Constructor for objects of class MyWorld.
     * 
     */   
    public DuckWorld()
    {   
        super(800, 457, 1);
        
        // Make sure actors are painted in the correct order.
        setPaintOrder(ScoreBoard.class, LevelNext.class, Crosshair.class, Duck.class, ScoreCounter.class, ShotCounter.class, WipeOut.class);
        
        // Add the initial actors
        populate();
        
        
        LevelInt.value = 1;
        
     }  
             
     
    /**
     * Checks if there are any ducks in the world,
     * Creates two ducks from the side of the world if no ducks are present.
     */
    public void act() 
    {
       /**
         * Level 1 and Level 2.
         */
        if ( LevelInt.value == 1 || LevelInt.value == 2)
        {
            List<Duck> ducks = getObjects(Duck.class);
            if (ducks.isEmpty())
                {
                    addObject(new Duck(), 0, Greenfoot.getRandomNumber(600));
                    addObject(new Duck(), 0, Greenfoot.getRandomNumber(600));    
                    ducksSeen+=2;
                }
        }
        /**
         * Level 3.
         */
        if (LevelInt.value == 3)
        {
            List<Duck> ducks = getObjects(Duck.class);
            if (ducks.isEmpty())
                {
                    addObject(new Duck(), 0, Greenfoot.getRandomNumber(600));
                    addObject(new Duck(), 0, Greenfoot.getRandomNumber(600));
                    addObject(new Duck(), 0, Greenfoot.getRandomNumber(600)); 
                    ducksSeen+=3;
                }            
        }
       
    }

    /**
     * Count one shot duck and add to the final score.
     */
    public void countPop()
    {
        /**
         * Level 1.
         */
        if ( LevelInt.value == 1)
        {
            scorecounter.add(20);          
        }
        /**
         * Level 2.
         */
        if ( LevelInt.value == 2)
        {
            scorecounter.add(50);          
        }
        /**
         * Level 3.
         */
        if ( LevelInt.value == 3)
        {
            scorecounter.add(100);          
        }
    }
    
    /**
     * Count number of ducks shot.
     */
    public void countShot()
    {
        shotcounter.add(1);
    }
    
    /**
     * Count number of ducks wiped out.
     */
    public void countWipe()
    {
        /**
         * Level 1
         */
        if ( LevelInt.value == 1)
        {
            shotcounter.add(2);
            scorecounter.add(40);
        }
        /**
         * Level 2.
         */
        if (LevelInt.value == 2)
        {
            shotcounter.add(2);
            scorecounter.add(100);
        }/**
         * Level 3.
         */
        if (LevelInt.value == 3)
        {
            shotcounter.add(3);    
            scorecounter.add(300);
        }

    }
    
    
    /**
     * Called when game is up. Stop running and display score.
     */
    public void gameOver() 
    {       
        addObject(new ScoreBoard(scorecounter.getValue()), getWidth()/2, getHeight()/2);
        Greenfoot.playSound("buzz.wav");
        ShotCounter.target = 0;
        ducksSeen = 0;
       Greenfoot.stop();
    }
    
    /**
     * Called when proceeding to next level. 
     */
    public void nextLevel() 
    {
        levelint.add(1);
        addObject(new LevelNext(levelint.getValue()), getWidth()/2, getHeight()/2);
        if(LevelInt.value == 1 || LevelInt.value == 2)
        {         
            ShotCounter.target = 0;
            ducksSeen = 2;
        }
        else if(LevelInt.value == 3)
        {
            ShotCounter.target = 0;
            ducksSeen = 3;
        }
    }

    /**
     * Populate the world with a crosshair and the counters.
     */
    private void populate()
    {
        addObject(scorecounter, 100, 440);
        addObject(new Crosshair(), 400,300);
        addObject(shotcounter, 760, 15);
        addObject(levelint, 760, 440);
        addObject(new WipeOut(), 650,430);
        addObject(new LevelNext(levelint.getValue()), getWidth()/2, getHeight()/2);
    }  
}
