import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.awt.Color;
import java.awt.Font;
import java.util.Calendar;

/**
 * The scoreBoard is used to display results on the screen. It can display some
 * text and several numbers.
 * 
 * @author M Kolling
 * @version 1.0
 */
public class LevelNext extends Actor
{
    public static final float FONT_SIZE = 48.0f;
    public static final int WIDTH = 500;
    public static final int HEIGHT = 300;
    public static int level = 1;
    
    
    private int prevSecond = -1;
    private int counter = 2;
    
    /**
     * Create a level indicator with dummy result for testing.
     */
    public LevelNext()
    {
        this(1);
        LevelInt.value = 1;
    }

    /**
     * Create a level indicator for the final result.
     */
    public LevelNext(int level)
    {
        makeImage("Level Indicator", "Level: ", level);

    }
    
    /**
     * Act
     */
    public void act()
    {
        deleteLevelBoard();
    }
    
    
    /**
     * Remove the object after a certain time
     */
    public void deleteLevelBoard()
    {
        Calendar calendar = Calendar.getInstance();
        int sec = calendar.get(Calendar.SECOND);
        if (counter == 0)
        {
            getWorld().removeObject(this);
        }
        if (sec != prevSecond )
        {
            prevSecond = sec;
            counter = counter - 1;
        }
    }
    /**
     * Make the level indicator image.
     */
    private void makeImage(String title, String prefix, int level)
    {
        GreenfootImage image = new GreenfootImage(WIDTH, HEIGHT);

        image.setColor(new Color(0, 0, 0, 160));
        image.fillRect(0, 0, WIDTH, HEIGHT);
        image.setColor(new Color(255, 163, 255, 100));
        image.fillRect(5, 5, WIDTH-10, HEIGHT-10);
        Font font = image.getFont();
        font = font.deriveFont(FONT_SIZE);
        image.setFont(font);
        image.setColor(Color.WHITE);
        image.drawString(title, 60, 100);
        image.drawString(prefix + level, 60, 200);
        setImage(image);
    }
}
